@@ -29,18 +29,48 @@ ergm.MEM<-function(model,
                    control_vals=NULL,
                    return.dydx=FALSE){
 
+  if(class(model)%in%"btergm"){
+    out<-ergm.MEM_boot(model=model,
+                       var1=var1,
+                       var2=var2,
+                       inter=inter,
+                       at.2=at.2,
+                       at.controls=at.controls,
+                       control_vals=control_vals,
+                       return.dydx=return.dydx)
+    return(out)
+  }
 
-  ##get edge probabilities
-  dyad.mat<-edge.prob2(model)[,-c(1)]
-  dyad.full.mat<-dyad.mat
-  start.drops<-ncol(dyad.mat)-5
-  dyad.mat<-dyad.mat[,-c(start.drops:ncol(dyad.mat))]
+  if(is.valued(model)){
+    out<-ergm.MEM_count(model=model,
+                        var1=var1,
+                        var2=var2,
+                        inter=inter,
+                        at.2=at.2,
+                        at.controls=at.controls,
+                        control_vals=control_vals,
+                        return.dydx=return.dydx)
+
+    return(out)
+  }
+
+  if(class(model$network)[1]%in%"mtergm"){
+    dyad.mat<-edge.prob2(model)[,-c(1)]
+    dyad.full.mat<-dyad.mat
+    start.drops<-ncol(dyad.mat)-5
+    dyad.mat<-dyad.mat[,-c(start.drops:ncol(dyad.mat))]
 
-  if(class(model)%in%"mtergm"|class(model)%in%"btergm"){
     vc <- stats::vcov(model@ergm)
     vc<-vc[!rownames(vc)%in%"edgecov.offsmat",!colnames(vc)%in%"edgecov.offsmat"]
+
+
   }else{
+
+    dyad.mat<-ergmMPLE(btergm::getformula(model))
+    dyad.mat<-dyad.mat$predictor
+    theta<-coef(model)
     vc <- stats::vcov(model)
+
   }
 
   if(class(model)%in%"mlergm"){
@@ -65,7 +95,10 @@ ergm.MEM<-function(model,
       for(i in 1:length(model$etamap$curved)){
         curved.term[i]<-model$etamap$curved[[i]]$from[2]
       }
-      theta<-theta[-c(curved.term)]
+    #  theta<-theta[-c(curved.term)]
+      theta<-ergm::ergm.eta(theta,model@ergm$etamap)
+      names(theta)<-colnames(dyad.mat[,-c(1)])
+
     }
 
   }else{
@@ -74,7 +107,10 @@ ergm.MEM<-function(model,
       for(i in 1:length(model$etamap$curved)){
         curved.term[i]<-model$etamap$curved[[i]]$from[2]
       }
-      theta<-theta[-c(curved.term)]
+      #theta<-theta[-c(curved.term)]
+      theta<-ergm::ergm.eta(theta,model$etamap)
+      names(theta)<-colnames(dyad.mat[,-c(1)])
+
     }
   }
 
@@ -110,6 +146,12 @@ ergm.MEM<-function(model,
     at.2<-sort(unique(dyad.mat[,var2]))
   }
 
+  if(class(model)%in%"mlergm"){
+    theta<-model$theta
+    vc<-solve(vc) #invert the fisher matrix
+  }else{
+    theta<-btergm::coef(model)
+  }
 
   ##marginal effects with no interaction
   if(is.null(var2)){
@@ -247,7 +289,15 @@ ergm.MEM<-function(model,
 
       dyad.submeans<-dyad.means
       dyad.submeans[var2]<-at.2[i]
-
+      if(class(model)%in%"mtergm"){
+        if(ergm::is.curved(model@ergm)){
+          theta<-ergm::ergm.eta(theta,model@ergm$etamap)
+        }
+      }else{
+        if(ergm::is.curved(model)){
+          theta<-ergm::ergm.eta(theta,model$etamap)
+        }
+      }
       #marginal effects for absolute differences
       if(!is.na(pmatch("absdiff",inter))){
         dyad.submeans[inter]<-abs(dyad.submeans[var1]-dyad.submeans[var2])
@@ -259,6 +309,12 @@ ergm.MEM<-function(model,
         p<-1/(1+exp(-(dyad.submeans%*%theta)))
 
         at.diffs<-abs(at.2[i]-dyad.submeans[var1])
+        if(class(model)%in%"mlergm"){
+          theta<-model$theta
+          vc<-solve(vc) #invert the fisher matrix
+        }else{
+          theta<-btergm::coef(model)
+        }
 
         MEM.fun<-function(theta){
 
@@ -275,6 +331,12 @@ ergm.MEM<-function(model,
         }
 
         p<-1/(1+exp(-(dyad.submeans%*%theta)))
+        if(class(model)%in%"mlergm"){
+          theta<-model$theta
+          vc<-solve(vc) #invert the fisher matrix
+        }else{
+          theta<-btergm::coef(model)
+        }
 
         MEM.fun<-function(theta){
 
